package com.shzg.project.worn.mapper;

import java.util.List;
import com.shzg.project.worn.domain.WornInboundBill;

/**
 * 入库库存Mapper接口
 * 
 * @author shzg
 * @date 2026-03-26
 */
public interface WornInboundBillMapper 
{
    /**
     * 查询入库库存
     * 
     * @param id 入库库存主键
     * @return 入库库存
     */
    public WornInboundBill selectWornInboundBillById(Long id);

    /**
     * 查询入库库存列表
     * 
     * @param wornInboundBill 入库库存
     * @return 入库库存集合
     */
    public List<WornInboundBill> selectWornInboundBillList(WornInboundBill wornInboundBill);

    /**
     * 新增入库库存
     * 
     * @param wornInboundBill 入库库存
     * @return 结果
     */
    public int insertWornInboundBill(WornInboundBill wornInboundBill);

    /**
     * 修改入库库存
     * 
     * @param wornInboundBill 入库库存
     * @return 结果
     */
    public int updateWornInboundBill(WornInboundBill wornInboundBill);

    /**
     * 删除入库库存
     * 
     * @param id 入库库存主键
     * @return 结果
     */
    public int deleteWornInboundBillById(Long id);

    /**
     * 批量删除入库库存
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWornInboundBillByIds(Long[] ids);

    /**
     * 根据单号查询入库单
     */
    public WornInboundBill selectWornInboundBillByBillNo(String billNo);

    /**
     * 根据ID更新入库单
     */
    public int updateWornInboundBillById(WornInboundBill bill);
}
